# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryOrganizationArgs', 'SentryOrganization']

@pulumi.input_type
class SentryOrganizationArgs:
    def __init__(__self__, *,
                 agree_terms: pulumi.Input[bool],
                 name: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SentryOrganization resource.
        :param pulumi.Input[bool] agree_terms: You agree to the applicable terms of service and privacy policy.
        :param pulumi.Input[str] name: The human readable name for the organization.
        :param pulumi.Input[str] slug: The unique URL slug for this organization.
        """
        pulumi.set(__self__, "agree_terms", agree_terms)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)

    @property
    @pulumi.getter(name="agreeTerms")
    def agree_terms(self) -> pulumi.Input[bool]:
        """
        You agree to the applicable terms of service and privacy policy.
        """
        return pulumi.get(self, "agree_terms")

    @agree_terms.setter
    def agree_terms(self, value: pulumi.Input[bool]):
        pulumi.set(self, "agree_terms", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The human readable name for the organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The unique URL slug for this organization.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)


@pulumi.input_type
class _SentryOrganizationState:
    def __init__(__self__, *,
                 agree_terms: Optional[pulumi.Input[bool]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SentryOrganization resources.
        :param pulumi.Input[bool] agree_terms: You agree to the applicable terms of service and privacy policy.
        :param pulumi.Input[str] internal_id: The internal ID for this organization.
        :param pulumi.Input[str] name: The human readable name for the organization.
        :param pulumi.Input[str] slug: The unique URL slug for this organization.
        """
        if agree_terms is not None:
            pulumi.set(__self__, "agree_terms", agree_terms)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)

    @property
    @pulumi.getter(name="agreeTerms")
    def agree_terms(self) -> Optional[pulumi.Input[bool]]:
        """
        You agree to the applicable terms of service and privacy policy.
        """
        return pulumi.get(self, "agree_terms")

    @agree_terms.setter
    def agree_terms(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "agree_terms", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this organization.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The human readable name for the organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The unique URL slug for this organization.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)


class SentryOrganization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agree_terms: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Sentry Organization resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create an organization
        default = sentry.SentryOrganization("default",
            name="My Organization",
            slug="my-organization",
            agree_terms=True)
        ```

        ## Import

        import using the organization slug from the URL:

        https://sentry.io/organizations/[org-slug]/issues/

        ```sh
        $ pulumi import sentry:index/sentryOrganization:SentryOrganization default org-slug
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] agree_terms: You agree to the applicable terms of service and privacy policy.
        :param pulumi.Input[str] name: The human readable name for the organization.
        :param pulumi.Input[str] slug: The unique URL slug for this organization.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryOrganizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Organization resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create an organization
        default = sentry.SentryOrganization("default",
            name="My Organization",
            slug="my-organization",
            agree_terms=True)
        ```

        ## Import

        import using the organization slug from the URL:

        https://sentry.io/organizations/[org-slug]/issues/

        ```sh
        $ pulumi import sentry:index/sentryOrganization:SentryOrganization default org-slug
        ```

        :param str resource_name: The name of the resource.
        :param SentryOrganizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryOrganizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agree_terms: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryOrganizationArgs.__new__(SentryOrganizationArgs)

            if agree_terms is None and not opts.urn:
                raise TypeError("Missing required property 'agree_terms'")
            __props__.__dict__["agree_terms"] = agree_terms
            __props__.__dict__["name"] = name
            __props__.__dict__["slug"] = slug
            __props__.__dict__["internal_id"] = None
        super(SentryOrganization, __self__).__init__(
            'sentry:index/sentryOrganization:SentryOrganization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agree_terms: Optional[pulumi.Input[bool]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            slug: Optional[pulumi.Input[str]] = None) -> 'SentryOrganization':
        """
        Get an existing SentryOrganization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] agree_terms: You agree to the applicable terms of service and privacy policy.
        :param pulumi.Input[str] internal_id: The internal ID for this organization.
        :param pulumi.Input[str] name: The human readable name for the organization.
        :param pulumi.Input[str] slug: The unique URL slug for this organization.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryOrganizationState.__new__(_SentryOrganizationState)

        __props__.__dict__["agree_terms"] = agree_terms
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["name"] = name
        __props__.__dict__["slug"] = slug
        return SentryOrganization(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="agreeTerms")
    def agree_terms(self) -> pulumi.Output[bool]:
        """
        You agree to the applicable terms of service and privacy policy.
        """
        return pulumi.get(self, "agree_terms")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this organization.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The human readable name for the organization.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        The unique URL slug for this organization.
        """
        return pulumi.get(self, "slug")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SentryMetricAlertArgs', 'SentryMetricAlert']

@pulumi.input_type
class SentryMetricAlertArgs:
    def __init__(__self__, *,
                 aggregate: pulumi.Input[str],
                 organization: pulumi.Input[str],
                 project: pulumi.Input[str],
                 query: pulumi.Input[str],
                 threshold_type: pulumi.Input[int],
                 time_window: pulumi.Input[float],
                 triggers: pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerArgs']]],
                 dataset: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 resolve_threshold: Optional[pulumi.Input[float]] = None):
        """
        The set of arguments for constructing a SentryMetricAlert resource.
        :param pulumi.Input[str] aggregate: The aggregation criteria to apply
        :param pulumi.Input[str] organization: The slug of the organization the metric alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the metric alert for.
        :param pulumi.Input[str] query: The query filter to apply
        :param pulumi.Input[int] threshold_type: The type of threshold
        :param pulumi.Input[float] time_window: The period to evaluate the Alert rule in minutes
        :param pulumi.Input[str] dataset: The Sentry Alert category
        :param pulumi.Input[str] environment: Perform Alert rule in a specific environment
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: The events type of dataset.
        :param pulumi.Input[str] name: The metric alert name.
        :param pulumi.Input[str] owner: Specifies the owner id of this Alert rule
        :param pulumi.Input[float] resolve_threshold: The value at which the Alert rule resolves
        """
        pulumi.set(__self__, "aggregate", aggregate)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "query", query)
        pulumi.set(__self__, "threshold_type", threshold_type)
        pulumi.set(__self__, "time_window", time_window)
        pulumi.set(__self__, "triggers", triggers)
        if dataset is not None:
            pulumi.set(__self__, "dataset", dataset)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if event_types is not None:
            pulumi.set(__self__, "event_types", event_types)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if resolve_threshold is not None:
            pulumi.set(__self__, "resolve_threshold", resolve_threshold)

    @property
    @pulumi.getter
    def aggregate(self) -> pulumi.Input[str]:
        """
        The aggregation criteria to apply
        """
        return pulumi.get(self, "aggregate")

    @aggregate.setter
    def aggregate(self, value: pulumi.Input[str]):
        pulumi.set(self, "aggregate", value)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the metric alert belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The slug of the project to create the metric alert for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def query(self) -> pulumi.Input[str]:
        """
        The query filter to apply
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: pulumi.Input[str]):
        pulumi.set(self, "query", value)

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> pulumi.Input[int]:
        """
        The type of threshold
        """
        return pulumi.get(self, "threshold_type")

    @threshold_type.setter
    def threshold_type(self, value: pulumi.Input[int]):
        pulumi.set(self, "threshold_type", value)

    @property
    @pulumi.getter(name="timeWindow")
    def time_window(self) -> pulumi.Input[float]:
        """
        The period to evaluate the Alert rule in minutes
        """
        return pulumi.get(self, "time_window")

    @time_window.setter
    def time_window(self, value: pulumi.Input[float]):
        pulumi.set(self, "time_window", value)

    @property
    @pulumi.getter
    def triggers(self) -> pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerArgs']]]:
        return pulumi.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerArgs']]]):
        pulumi.set(self, "triggers", value)

    @property
    @pulumi.getter
    def dataset(self) -> Optional[pulumi.Input[str]]:
        """
        The Sentry Alert category
        """
        return pulumi.get(self, "dataset")

    @dataset.setter
    def dataset(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataset", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Perform Alert rule in a specific environment
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The events type of dataset.
        """
        return pulumi.get(self, "event_types")

    @event_types.setter
    def event_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "event_types", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The metric alert name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the owner id of this Alert rule
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> Optional[pulumi.Input[float]]:
        """
        The value at which the Alert rule resolves
        """
        return pulumi.get(self, "resolve_threshold")

    @resolve_threshold.setter
    def resolve_threshold(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "resolve_threshold", value)


@pulumi.input_type
class _SentryMetricAlertState:
    def __init__(__self__, *,
                 aggregate: Optional[pulumi.Input[str]] = None,
                 dataset: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 resolve_threshold: Optional[pulumi.Input[float]] = None,
                 threshold_type: Optional[pulumi.Input[int]] = None,
                 time_window: Optional[pulumi.Input[float]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerArgs']]]] = None):
        """
        Input properties used for looking up and filtering SentryMetricAlert resources.
        :param pulumi.Input[str] aggregate: The aggregation criteria to apply
        :param pulumi.Input[str] dataset: The Sentry Alert category
        :param pulumi.Input[str] environment: Perform Alert rule in a specific environment
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: The events type of dataset.
        :param pulumi.Input[str] internal_id: The internal ID for this metric alert.
        :param pulumi.Input[str] name: The metric alert name.
        :param pulumi.Input[str] organization: The slug of the organization the metric alert belongs to.
        :param pulumi.Input[str] owner: Specifies the owner id of this Alert rule
        :param pulumi.Input[str] project: The slug of the project to create the metric alert for.
        :param pulumi.Input[str] query: The query filter to apply
        :param pulumi.Input[float] resolve_threshold: The value at which the Alert rule resolves
        :param pulumi.Input[int] threshold_type: The type of threshold
        :param pulumi.Input[float] time_window: The period to evaluate the Alert rule in minutes
        """
        if aggregate is not None:
            pulumi.set(__self__, "aggregate", aggregate)
        if dataset is not None:
            pulumi.set(__self__, "dataset", dataset)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if event_types is not None:
            pulumi.set(__self__, "event_types", event_types)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if query is not None:
            pulumi.set(__self__, "query", query)
        if resolve_threshold is not None:
            pulumi.set(__self__, "resolve_threshold", resolve_threshold)
        if threshold_type is not None:
            pulumi.set(__self__, "threshold_type", threshold_type)
        if time_window is not None:
            pulumi.set(__self__, "time_window", time_window)
        if triggers is not None:
            pulumi.set(__self__, "triggers", triggers)

    @property
    @pulumi.getter
    def aggregate(self) -> Optional[pulumi.Input[str]]:
        """
        The aggregation criteria to apply
        """
        return pulumi.get(self, "aggregate")

    @aggregate.setter
    def aggregate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aggregate", value)

    @property
    @pulumi.getter
    def dataset(self) -> Optional[pulumi.Input[str]]:
        """
        The Sentry Alert category
        """
        return pulumi.get(self, "dataset")

    @dataset.setter
    def dataset(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataset", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Perform Alert rule in a specific environment
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The events type of dataset.
        """
        return pulumi.get(self, "event_types")

    @event_types.setter
    def event_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "event_types", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this metric alert.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The metric alert name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the metric alert belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the owner id of this Alert rule
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the project to create the metric alert for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def query(self) -> Optional[pulumi.Input[str]]:
        """
        The query filter to apply
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "query", value)

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> Optional[pulumi.Input[float]]:
        """
        The value at which the Alert rule resolves
        """
        return pulumi.get(self, "resolve_threshold")

    @resolve_threshold.setter
    def resolve_threshold(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "resolve_threshold", value)

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> Optional[pulumi.Input[int]]:
        """
        The type of threshold
        """
        return pulumi.get(self, "threshold_type")

    @threshold_type.setter
    def threshold_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "threshold_type", value)

    @property
    @pulumi.getter(name="timeWindow")
    def time_window(self) -> Optional[pulumi.Input[float]]:
        """
        The period to evaluate the Alert rule in minutes
        """
        return pulumi.get(self, "time_window")

    @time_window.setter
    def time_window(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "time_window", value)

    @property
    @pulumi.getter
    def triggers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerArgs']]]]:
        return pulumi.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerArgs']]]]):
        pulumi.set(self, "triggers", value)


class SentryMetricAlert(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aggregate: Optional[pulumi.Input[str]] = None,
                 dataset: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 resolve_threshold: Optional[pulumi.Input[float]] = None,
                 threshold_type: Optional[pulumi.Input[int]] = None,
                 time_window: Optional[pulumi.Input[float]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SentryMetricAlertTriggerArgs', 'SentryMetricAlertTriggerArgsDict']]]]] = None,
                 __props__=None):
        """
        Sentry Metric Alert resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_sentry as sentry
        import pulumiverse_sentry as sentry

        slack = sentry.get_sentry_organization_integration(organization=main_sentry_project["organization"],
            provider_key="slack",
            name="Slack Workspace")
        main = sentry.SentryMetricAlert("main",
            organization=main_sentry_project["organization"],
            project=main_sentry_project["id"],
            name="My metric alert",
            dataset="events",
            query="",
            aggregate="count()",
            time_window=60,
            threshold_type=0,
            resolve_threshold=0,
            triggers=[
                {
                    "actions": [{
                        "type": "email",
                        "target_type": "team",
                        "target_identifier": main_sentry_team["teamId"],
                    }],
                    "alert_threshold": 300,
                    "label": "critical",
                    "threshold_type": 0,
                },
                {
                    "actions": [{
                        "type": "slack",
                        "target_type": "specific",
                        "target_identifier": "#slack-channel",
                        "integration_id": slack.id,
                    }],
                    "alert_threshold": 300,
                    "label": "critical",
                    "threshold_type": 0,
                },
                {
                    "alert_threshold": 100,
                    "label": "warning",
                    "threshold_type": 0,
                },
            ])
        ```

        ## Import

        import using the organization, project slugs and rule id from the URL:

        https://sentry.io/organizations/[org-slug]/projects/[project-slug]/

        https://sentry.io/organizations/[org-slug]/alerts/rules/details/[rule-id]/

        or

        https://sentry.io/organizations/[org-slug]/alerts/metric-rules/[project-slug]/[rule-id]/

        ```sh
        $ pulumi import sentry:index/sentryMetricAlert:SentryMetricAlert default org-slug/project-slug/rule-id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aggregate: The aggregation criteria to apply
        :param pulumi.Input[str] dataset: The Sentry Alert category
        :param pulumi.Input[str] environment: Perform Alert rule in a specific environment
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: The events type of dataset.
        :param pulumi.Input[str] name: The metric alert name.
        :param pulumi.Input[str] organization: The slug of the organization the metric alert belongs to.
        :param pulumi.Input[str] owner: Specifies the owner id of this Alert rule
        :param pulumi.Input[str] project: The slug of the project to create the metric alert for.
        :param pulumi.Input[str] query: The query filter to apply
        :param pulumi.Input[float] resolve_threshold: The value at which the Alert rule resolves
        :param pulumi.Input[int] threshold_type: The type of threshold
        :param pulumi.Input[float] time_window: The period to evaluate the Alert rule in minutes
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryMetricAlertArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Metric Alert resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_sentry as sentry
        import pulumiverse_sentry as sentry

        slack = sentry.get_sentry_organization_integration(organization=main_sentry_project["organization"],
            provider_key="slack",
            name="Slack Workspace")
        main = sentry.SentryMetricAlert("main",
            organization=main_sentry_project["organization"],
            project=main_sentry_project["id"],
            name="My metric alert",
            dataset="events",
            query="",
            aggregate="count()",
            time_window=60,
            threshold_type=0,
            resolve_threshold=0,
            triggers=[
                {
                    "actions": [{
                        "type": "email",
                        "target_type": "team",
                        "target_identifier": main_sentry_team["teamId"],
                    }],
                    "alert_threshold": 300,
                    "label": "critical",
                    "threshold_type": 0,
                },
                {
                    "actions": [{
                        "type": "slack",
                        "target_type": "specific",
                        "target_identifier": "#slack-channel",
                        "integration_id": slack.id,
                    }],
                    "alert_threshold": 300,
                    "label": "critical",
                    "threshold_type": 0,
                },
                {
                    "alert_threshold": 100,
                    "label": "warning",
                    "threshold_type": 0,
                },
            ])
        ```

        ## Import

        import using the organization, project slugs and rule id from the URL:

        https://sentry.io/organizations/[org-slug]/projects/[project-slug]/

        https://sentry.io/organizations/[org-slug]/alerts/rules/details/[rule-id]/

        or

        https://sentry.io/organizations/[org-slug]/alerts/metric-rules/[project-slug]/[rule-id]/

        ```sh
        $ pulumi import sentry:index/sentryMetricAlert:SentryMetricAlert default org-slug/project-slug/rule-id
        ```

        :param str resource_name: The name of the resource.
        :param SentryMetricAlertArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryMetricAlertArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aggregate: Optional[pulumi.Input[str]] = None,
                 dataset: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 resolve_threshold: Optional[pulumi.Input[float]] = None,
                 threshold_type: Optional[pulumi.Input[int]] = None,
                 time_window: Optional[pulumi.Input[float]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SentryMetricAlertTriggerArgs', 'SentryMetricAlertTriggerArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryMetricAlertArgs.__new__(SentryMetricAlertArgs)

            if aggregate is None and not opts.urn:
                raise TypeError("Missing required property 'aggregate'")
            __props__.__dict__["aggregate"] = aggregate
            __props__.__dict__["dataset"] = dataset
            __props__.__dict__["environment"] = environment
            __props__.__dict__["event_types"] = event_types
            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            __props__.__dict__["owner"] = owner
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if query is None and not opts.urn:
                raise TypeError("Missing required property 'query'")
            __props__.__dict__["query"] = query
            __props__.__dict__["resolve_threshold"] = resolve_threshold
            if threshold_type is None and not opts.urn:
                raise TypeError("Missing required property 'threshold_type'")
            __props__.__dict__["threshold_type"] = threshold_type
            if time_window is None and not opts.urn:
                raise TypeError("Missing required property 'time_window'")
            __props__.__dict__["time_window"] = time_window
            if triggers is None and not opts.urn:
                raise TypeError("Missing required property 'triggers'")
            __props__.__dict__["triggers"] = triggers
            __props__.__dict__["internal_id"] = None
        super(SentryMetricAlert, __self__).__init__(
            'sentry:index/sentryMetricAlert:SentryMetricAlert',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aggregate: Optional[pulumi.Input[str]] = None,
            dataset: Optional[pulumi.Input[str]] = None,
            environment: Optional[pulumi.Input[str]] = None,
            event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            query: Optional[pulumi.Input[str]] = None,
            resolve_threshold: Optional[pulumi.Input[float]] = None,
            threshold_type: Optional[pulumi.Input[int]] = None,
            time_window: Optional[pulumi.Input[float]] = None,
            triggers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SentryMetricAlertTriggerArgs', 'SentryMetricAlertTriggerArgsDict']]]]] = None) -> 'SentryMetricAlert':
        """
        Get an existing SentryMetricAlert resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aggregate: The aggregation criteria to apply
        :param pulumi.Input[str] dataset: The Sentry Alert category
        :param pulumi.Input[str] environment: Perform Alert rule in a specific environment
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: The events type of dataset.
        :param pulumi.Input[str] internal_id: The internal ID for this metric alert.
        :param pulumi.Input[str] name: The metric alert name.
        :param pulumi.Input[str] organization: The slug of the organization the metric alert belongs to.
        :param pulumi.Input[str] owner: Specifies the owner id of this Alert rule
        :param pulumi.Input[str] project: The slug of the project to create the metric alert for.
        :param pulumi.Input[str] query: The query filter to apply
        :param pulumi.Input[float] resolve_threshold: The value at which the Alert rule resolves
        :param pulumi.Input[int] threshold_type: The type of threshold
        :param pulumi.Input[float] time_window: The period to evaluate the Alert rule in minutes
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryMetricAlertState.__new__(_SentryMetricAlertState)

        __props__.__dict__["aggregate"] = aggregate
        __props__.__dict__["dataset"] = dataset
        __props__.__dict__["environment"] = environment
        __props__.__dict__["event_types"] = event_types
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["name"] = name
        __props__.__dict__["organization"] = organization
        __props__.__dict__["owner"] = owner
        __props__.__dict__["project"] = project
        __props__.__dict__["query"] = query
        __props__.__dict__["resolve_threshold"] = resolve_threshold
        __props__.__dict__["threshold_type"] = threshold_type
        __props__.__dict__["time_window"] = time_window
        __props__.__dict__["triggers"] = triggers
        return SentryMetricAlert(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def aggregate(self) -> pulumi.Output[str]:
        """
        The aggregation criteria to apply
        """
        return pulumi.get(self, "aggregate")

    @property
    @pulumi.getter
    def dataset(self) -> pulumi.Output[Optional[str]]:
        """
        The Sentry Alert category
        """
        return pulumi.get(self, "dataset")

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output[str]:
        """
        Perform Alert rule in a specific environment
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The events type of dataset.
        """
        return pulumi.get(self, "event_types")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this metric alert.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The metric alert name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the metric alert belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Specifies the owner id of this Alert rule
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The slug of the project to create the metric alert for.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def query(self) -> pulumi.Output[str]:
        """
        The query filter to apply
        """
        return pulumi.get(self, "query")

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> pulumi.Output[Optional[float]]:
        """
        The value at which the Alert rule resolves
        """
        return pulumi.get(self, "resolve_threshold")

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> pulumi.Output[int]:
        """
        The type of threshold
        """
        return pulumi.get(self, "threshold_type")

    @property
    @pulumi.getter(name="timeWindow")
    def time_window(self) -> pulumi.Output[float]:
        """
        The period to evaluate the Alert rule in minutes
        """
        return pulumi.get(self, "time_window")

    @property
    @pulumi.getter
    def triggers(self) -> pulumi.Output[Sequence['outputs.SentryMetricAlertTrigger']]:
        return pulumi.get(self, "triggers")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryOrganizationCodeMappingArgs', 'SentryOrganizationCodeMapping']

@pulumi.input_type
class SentryOrganizationCodeMappingArgs:
    def __init__(__self__, *,
                 default_branch: pulumi.Input[str],
                 integration_id: pulumi.Input[str],
                 organization: pulumi.Input[str],
                 project_id: pulumi.Input[str],
                 repository_id: pulumi.Input[str],
                 source_root: Optional[pulumi.Input[str]] = None,
                 stack_root: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SentryOrganizationCodeMapping resource.
        :param pulumi.Input[str] default_branch: Default branch of your code we fall back to if you do not have commit tracking set up.
        :param pulumi.Input[str] integration_id: Sentry Organization Integration ID.
        :param pulumi.Input[str] organization: The slug of the organization the code mapping is under.
        :param pulumi.Input[str] project_id: Sentry Project ID.
        :param pulumi.Input[str] repository_id: Sentry Organization Repository ID.
        :param pulumi.Input[str] source_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        :param pulumi.Input[str] stack_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        pulumi.set(__self__, "default_branch", default_branch)
        pulumi.set(__self__, "integration_id", integration_id)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "repository_id", repository_id)
        if source_root is not None:
            pulumi.set(__self__, "source_root", source_root)
        if stack_root is not None:
            pulumi.set(__self__, "stack_root", stack_root)

    @property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> pulumi.Input[str]:
        """
        Default branch of your code we fall back to if you do not have commit tracking set up.
        """
        return pulumi.get(self, "default_branch")

    @default_branch.setter
    def default_branch(self, value: pulumi.Input[str]):
        pulumi.set(self, "default_branch", value)

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> pulumi.Input[str]:
        """
        Sentry Organization Integration ID.
        """
        return pulumi.get(self, "integration_id")

    @integration_id.setter
    def integration_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_id", value)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the code mapping is under.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        Sentry Project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="repositoryId")
    def repository_id(self) -> pulumi.Input[str]:
        """
        Sentry Organization Repository ID.
        """
        return pulumi.get(self, "repository_id")

    @repository_id.setter
    def repository_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository_id", value)

    @property
    @pulumi.getter(name="sourceRoot")
    def source_root(self) -> Optional[pulumi.Input[str]]:
        """
        https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        return pulumi.get(self, "source_root")

    @source_root.setter
    def source_root(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_root", value)

    @property
    @pulumi.getter(name="stackRoot")
    def stack_root(self) -> Optional[pulumi.Input[str]]:
        """
        https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        return pulumi.get(self, "stack_root")

    @stack_root.setter
    def stack_root(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stack_root", value)


@pulumi.input_type
class _SentryOrganizationCodeMappingState:
    def __init__(__self__, *,
                 default_branch: Optional[pulumi.Input[str]] = None,
                 integration_id: Optional[pulumi.Input[str]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 repository_id: Optional[pulumi.Input[str]] = None,
                 source_root: Optional[pulumi.Input[str]] = None,
                 stack_root: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SentryOrganizationCodeMapping resources.
        :param pulumi.Input[str] default_branch: Default branch of your code we fall back to if you do not have commit tracking set up.
        :param pulumi.Input[str] integration_id: Sentry Organization Integration ID.
        :param pulumi.Input[str] internal_id: The internal ID for this resource.
        :param pulumi.Input[str] organization: The slug of the organization the code mapping is under.
        :param pulumi.Input[str] project_id: Sentry Project ID.
        :param pulumi.Input[str] repository_id: Sentry Organization Repository ID.
        :param pulumi.Input[str] source_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        :param pulumi.Input[str] stack_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        if default_branch is not None:
            pulumi.set(__self__, "default_branch", default_branch)
        if integration_id is not None:
            pulumi.set(__self__, "integration_id", integration_id)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repository_id is not None:
            pulumi.set(__self__, "repository_id", repository_id)
        if source_root is not None:
            pulumi.set(__self__, "source_root", source_root)
        if stack_root is not None:
            pulumi.set(__self__, "stack_root", stack_root)

    @property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> Optional[pulumi.Input[str]]:
        """
        Default branch of your code we fall back to if you do not have commit tracking set up.
        """
        return pulumi.get(self, "default_branch")

    @default_branch.setter
    def default_branch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_branch", value)

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> Optional[pulumi.Input[str]]:
        """
        Sentry Organization Integration ID.
        """
        return pulumi.get(self, "integration_id")

    @integration_id.setter
    def integration_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "integration_id", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this resource.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the code mapping is under.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        Sentry Project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="repositoryId")
    def repository_id(self) -> Optional[pulumi.Input[str]]:
        """
        Sentry Organization Repository ID.
        """
        return pulumi.get(self, "repository_id")

    @repository_id.setter
    def repository_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository_id", value)

    @property
    @pulumi.getter(name="sourceRoot")
    def source_root(self) -> Optional[pulumi.Input[str]]:
        """
        https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        return pulumi.get(self, "source_root")

    @source_root.setter
    def source_root(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_root", value)

    @property
    @pulumi.getter(name="stackRoot")
    def stack_root(self) -> Optional[pulumi.Input[str]]:
        """
        https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        return pulumi.get(self, "stack_root")

    @stack_root.setter
    def stack_root(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stack_root", value)


class SentryOrganizationCodeMapping(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_branch: Optional[pulumi.Input[str]] = None,
                 integration_id: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 repository_id: Optional[pulumi.Input[str]] = None,
                 source_root: Optional[pulumi.Input[str]] = None,
                 stack_root: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Sentry Organization Code Mapping resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_sentry as sentry
        import pulumiverse_sentry as sentry

        # Retrieve the Github organization integration
        github = sentry.get_sentry_organization_integration(organization="my-organization",
            provider_key="github",
            name="my-github-organization")
        this = sentry.SentryProject("this",
            organization="my-organization",
            team="my-team",
            name="Web App",
            slug="web-app",
            platform="javascript",
            resolve_age=720)
        this_sentry_organization_repository_github = sentry.SentryOrganizationRepositoryGithub("this",
            organization="my-organization",
            integration_id=github.internal_id,
            identifier="my-github-organization/my-github-repo")
        this_sentry_organization_code_mapping = sentry.SentryOrganizationCodeMapping("this",
            organization="my-organization",
            integration_id=github.internal_id,
            repository_id=this_sentry_organization_repository_github.internal_id,
            project_id=this.internal_id,
            default_branch="main",
            stack_root="/",
            source_root="src/")
        ```

        ## Import

        import using the organization slug from the URL:

        https://sentry.io/settings/[org-slug]/integrations/github/[org-integration-id]/

        and inspect network tab for request to https://sentry.io/api/0/organizations/[org-slug]/code-mappings/

        find the corresponding list element and reference [code-mapping-id] from the key "id"

        ```sh
        $ pulumi import sentry:index/sentryOrganizationCodeMapping:SentryOrganizationCodeMapping this org-slug/31347
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_branch: Default branch of your code we fall back to if you do not have commit tracking set up.
        :param pulumi.Input[str] integration_id: Sentry Organization Integration ID.
        :param pulumi.Input[str] organization: The slug of the organization the code mapping is under.
        :param pulumi.Input[str] project_id: Sentry Project ID.
        :param pulumi.Input[str] repository_id: Sentry Organization Repository ID.
        :param pulumi.Input[str] source_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        :param pulumi.Input[str] stack_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryOrganizationCodeMappingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Organization Code Mapping resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_sentry as sentry
        import pulumiverse_sentry as sentry

        # Retrieve the Github organization integration
        github = sentry.get_sentry_organization_integration(organization="my-organization",
            provider_key="github",
            name="my-github-organization")
        this = sentry.SentryProject("this",
            organization="my-organization",
            team="my-team",
            name="Web App",
            slug="web-app",
            platform="javascript",
            resolve_age=720)
        this_sentry_organization_repository_github = sentry.SentryOrganizationRepositoryGithub("this",
            organization="my-organization",
            integration_id=github.internal_id,
            identifier="my-github-organization/my-github-repo")
        this_sentry_organization_code_mapping = sentry.SentryOrganizationCodeMapping("this",
            organization="my-organization",
            integration_id=github.internal_id,
            repository_id=this_sentry_organization_repository_github.internal_id,
            project_id=this.internal_id,
            default_branch="main",
            stack_root="/",
            source_root="src/")
        ```

        ## Import

        import using the organization slug from the URL:

        https://sentry.io/settings/[org-slug]/integrations/github/[org-integration-id]/

        and inspect network tab for request to https://sentry.io/api/0/organizations/[org-slug]/code-mappings/

        find the corresponding list element and reference [code-mapping-id] from the key "id"

        ```sh
        $ pulumi import sentry:index/sentryOrganizationCodeMapping:SentryOrganizationCodeMapping this org-slug/31347
        ```

        :param str resource_name: The name of the resource.
        :param SentryOrganizationCodeMappingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryOrganizationCodeMappingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_branch: Optional[pulumi.Input[str]] = None,
                 integration_id: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 repository_id: Optional[pulumi.Input[str]] = None,
                 source_root: Optional[pulumi.Input[str]] = None,
                 stack_root: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryOrganizationCodeMappingArgs.__new__(SentryOrganizationCodeMappingArgs)

            if default_branch is None and not opts.urn:
                raise TypeError("Missing required property 'default_branch'")
            __props__.__dict__["default_branch"] = default_branch
            if integration_id is None and not opts.urn:
                raise TypeError("Missing required property 'integration_id'")
            __props__.__dict__["integration_id"] = integration_id
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if repository_id is None and not opts.urn:
                raise TypeError("Missing required property 'repository_id'")
            __props__.__dict__["repository_id"] = repository_id
            __props__.__dict__["source_root"] = source_root
            __props__.__dict__["stack_root"] = stack_root
            __props__.__dict__["internal_id"] = None
        super(SentryOrganizationCodeMapping, __self__).__init__(
            'sentry:index/sentryOrganizationCodeMapping:SentryOrganizationCodeMapping',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_branch: Optional[pulumi.Input[str]] = None,
            integration_id: Optional[pulumi.Input[str]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            repository_id: Optional[pulumi.Input[str]] = None,
            source_root: Optional[pulumi.Input[str]] = None,
            stack_root: Optional[pulumi.Input[str]] = None) -> 'SentryOrganizationCodeMapping':
        """
        Get an existing SentryOrganizationCodeMapping resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_branch: Default branch of your code we fall back to if you do not have commit tracking set up.
        :param pulumi.Input[str] integration_id: Sentry Organization Integration ID.
        :param pulumi.Input[str] internal_id: The internal ID for this resource.
        :param pulumi.Input[str] organization: The slug of the organization the code mapping is under.
        :param pulumi.Input[str] project_id: Sentry Project ID.
        :param pulumi.Input[str] repository_id: Sentry Organization Repository ID.
        :param pulumi.Input[str] source_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        :param pulumi.Input[str] stack_root: https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryOrganizationCodeMappingState.__new__(_SentryOrganizationCodeMappingState)

        __props__.__dict__["default_branch"] = default_branch
        __props__.__dict__["integration_id"] = integration_id
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["organization"] = organization
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["repository_id"] = repository_id
        __props__.__dict__["source_root"] = source_root
        __props__.__dict__["stack_root"] = stack_root
        return SentryOrganizationCodeMapping(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> pulumi.Output[str]:
        """
        Default branch of your code we fall back to if you do not have commit tracking set up.
        """
        return pulumi.get(self, "default_branch")

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> pulumi.Output[str]:
        """
        Sentry Organization Integration ID.
        """
        return pulumi.get(self, "integration_id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this resource.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the code mapping is under.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        Sentry Project ID.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="repositoryId")
    def repository_id(self) -> pulumi.Output[str]:
        """
        Sentry Organization Repository ID.
        """
        return pulumi.get(self, "repository_id")

    @property
    @pulumi.getter(name="sourceRoot")
    def source_root(self) -> pulumi.Output[Optional[str]]:
        """
        https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        return pulumi.get(self, "source_root")

    @property
    @pulumi.getter(name="stackRoot")
    def stack_root(self) -> pulumi.Output[Optional[str]]:
        """
        https://docs.sentry.io/product/integrations/source-code-mgmt/github/#stack-trace-linking
        """
        return pulumi.get(self, "stack_root")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSentryTeamResult',
    'AwaitableGetSentryTeamResult',
    'get_sentry_team',
    'get_sentry_team_output',
]

@pulumi.output_type
class GetSentryTeamResult:
    """
    A collection of values returned by getSentryTeam.
    """
    def __init__(__self__, has_access=None, id=None, internal_id=None, is_member=None, is_pending=None, name=None, organization=None, slug=None):
        if has_access and not isinstance(has_access, bool):
            raise TypeError("Expected argument 'has_access' to be a bool")
        pulumi.set(__self__, "has_access", has_access)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_id and not isinstance(internal_id, str):
            raise TypeError("Expected argument 'internal_id' to be a str")
        pulumi.set(__self__, "internal_id", internal_id)
        if is_member and not isinstance(is_member, bool):
            raise TypeError("Expected argument 'is_member' to be a bool")
        pulumi.set(__self__, "is_member", is_member)
        if is_pending and not isinstance(is_pending, bool):
            raise TypeError("Expected argument 'is_pending' to be a bool")
        pulumi.set(__self__, "is_pending", is_pending)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)

    @property
    @pulumi.getter(name="hasAccess")
    def has_access(self) -> bool:
        return pulumi.get(self, "has_access")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> str:
        """
        The internal ID for this team.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter(name="isMember")
    def is_member(self) -> bool:
        return pulumi.get(self, "is_member")

    @property
    @pulumi.getter(name="isPending")
    def is_pending(self) -> bool:
        return pulumi.get(self, "is_pending")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The human readable name for this organization.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The slug of the organization the team should be created for.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def slug(self) -> str:
        """
        The unique URL slug for this team.
        """
        return pulumi.get(self, "slug")


class AwaitableGetSentryTeamResult(GetSentryTeamResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryTeamResult(
            has_access=self.has_access,
            id=self.id,
            internal_id=self.internal_id,
            is_member=self.is_member,
            is_pending=self.is_pending,
            name=self.name,
            organization=self.organization,
            slug=self.slug)


def get_sentry_team(organization: Optional[str] = None,
                    slug: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryTeamResult:
    """
    Sentry Team data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve a team
    default = sentry.get_sentry_team(organization="my-organization",
        slug="my-team")
    ```


    :param str organization: The slug of the organization the team should be created for.
    :param str slug: The unique URL slug for this team.
    """
    __args__ = dict()
    __args__['organization'] = organization
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryTeam:getSentryTeam', __args__, opts=opts, typ=GetSentryTeamResult).value

    return AwaitableGetSentryTeamResult(
        has_access=pulumi.get(__ret__, 'has_access'),
        id=pulumi.get(__ret__, 'id'),
        internal_id=pulumi.get(__ret__, 'internal_id'),
        is_member=pulumi.get(__ret__, 'is_member'),
        is_pending=pulumi.get(__ret__, 'is_pending'),
        name=pulumi.get(__ret__, 'name'),
        organization=pulumi.get(__ret__, 'organization'),
        slug=pulumi.get(__ret__, 'slug'))
def get_sentry_team_output(organization: Optional[pulumi.Input[str]] = None,
                           slug: Optional[pulumi.Input[str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryTeamResult]:
    """
    Sentry Team data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve a team
    default = sentry.get_sentry_team(organization="my-organization",
        slug="my-team")
    ```


    :param str organization: The slug of the organization the team should be created for.
    :param str slug: The unique URL slug for this team.
    """
    __args__ = dict()
    __args__['organization'] = organization
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryTeam:getSentryTeam', __args__, opts=opts, typ=GetSentryTeamResult)
    return __ret__.apply(lambda __response__: GetSentryTeamResult(
        has_access=pulumi.get(__response__, 'has_access'),
        id=pulumi.get(__response__, 'id'),
        internal_id=pulumi.get(__response__, 'internal_id'),
        is_member=pulumi.get(__response__, 'is_member'),
        is_pending=pulumi.get(__response__, 'is_pending'),
        name=pulumi.get(__response__, 'name'),
        organization=pulumi.get(__response__, 'organization'),
        slug=pulumi.get(__response__, 'slug')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryPluginArgs', 'SentryPlugin']

@pulumi.input_type
class SentryPluginArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[str],
                 plugin: pulumi.Input[str],
                 project: pulumi.Input[str],
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SentryPlugin resource.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] plugin: Plugin ID.
        :param pulumi.Input[str] project: The slug of the project to create the plugin for.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Plugin config.
        """
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "plugin", plugin)
        pulumi.set(__self__, "project", project)
        if config is not None:
            pulumi.set(__self__, "config", config)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the project belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def plugin(self) -> pulumi.Input[str]:
        """
        Plugin ID.
        """
        return pulumi.get(self, "plugin")

    @plugin.setter
    def plugin(self, value: pulumi.Input[str]):
        pulumi.set(self, "plugin", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The slug of the project to create the plugin for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Plugin config.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config", value)


@pulumi.input_type
class _SentryPluginState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 plugin: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SentryPlugin resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Plugin config.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] plugin: Plugin ID.
        :param pulumi.Input[str] project: The slug of the project to create the plugin for.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if plugin is not None:
            pulumi.set(__self__, "plugin", plugin)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Plugin config.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the project belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def plugin(self) -> Optional[pulumi.Input[str]]:
        """
        Plugin ID.
        """
        return pulumi.get(self, "plugin")

    @plugin.setter
    def plugin(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "plugin", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the project to create the plugin for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class SentryPlugin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 plugin: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Sentry Plugin resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a plugin
        default = sentry.SentryPlugin("default",
            organization="my-organization",
            project="web-app",
            plugin="slack",
            config={
                "webhook": "slack://webhook",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Plugin config.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] plugin: Plugin ID.
        :param pulumi.Input[str] project: The slug of the project to create the plugin for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryPluginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Plugin resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a plugin
        default = sentry.SentryPlugin("default",
            organization="my-organization",
            project="web-app",
            plugin="slack",
            config={
                "webhook": "slack://webhook",
            })
        ```

        :param str resource_name: The name of the resource.
        :param SentryPluginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryPluginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 plugin: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryPluginArgs.__new__(SentryPluginArgs)

            __props__.__dict__["config"] = config
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if plugin is None and not opts.urn:
                raise TypeError("Missing required property 'plugin'")
            __props__.__dict__["plugin"] = plugin
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
        super(SentryPlugin, __self__).__init__(
            'sentry:index/sentryPlugin:SentryPlugin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            plugin: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'SentryPlugin':
        """
        Get an existing SentryPlugin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Plugin config.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] plugin: Plugin ID.
        :param pulumi.Input[str] project: The slug of the project to create the plugin for.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryPluginState.__new__(_SentryPluginState)

        __props__.__dict__["config"] = config
        __props__.__dict__["organization"] = organization
        __props__.__dict__["plugin"] = plugin
        __props__.__dict__["project"] = project
        return SentryPlugin(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Plugin config.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the project belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def plugin(self) -> pulumi.Output[str]:
        """
        Plugin ID.
        """
        return pulumi.get(self, "plugin")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The slug of the project to create the plugin for.
        """
        return pulumi.get(self, "project")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSentryOrganizationResult',
    'AwaitableGetSentryOrganizationResult',
    'get_sentry_organization',
    'get_sentry_organization_output',
]

@pulumi.output_type
class GetSentryOrganizationResult:
    """
    A collection of values returned by getSentryOrganization.
    """
    def __init__(__self__, id=None, internal_id=None, name=None, slug=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_id and not isinstance(internal_id, str):
            raise TypeError("Expected argument 'internal_id' to be a str")
        pulumi.set(__self__, "internal_id", internal_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> str:
        """
        The internal ID for this organization.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The human readable name for this organization.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def slug(self) -> str:
        """
        The unique URL slug for this organization.
        """
        return pulumi.get(self, "slug")


class AwaitableGetSentryOrganizationResult(GetSentryOrganizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryOrganizationResult(
            id=self.id,
            internal_id=self.internal_id,
            name=self.name,
            slug=self.slug)


def get_sentry_organization(slug: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryOrganizationResult:
    """
    Sentry Organization data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve an organization
    org = sentry.get_sentry_organization(slug="my-organization")
    ```


    :param str slug: The unique URL slug for this organization.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryOrganization:getSentryOrganization', __args__, opts=opts, typ=GetSentryOrganizationResult).value

    return AwaitableGetSentryOrganizationResult(
        id=pulumi.get(__ret__, 'id'),
        internal_id=pulumi.get(__ret__, 'internal_id'),
        name=pulumi.get(__ret__, 'name'),
        slug=pulumi.get(__ret__, 'slug'))
def get_sentry_organization_output(slug: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryOrganizationResult]:
    """
    Sentry Organization data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve an organization
    org = sentry.get_sentry_organization(slug="my-organization")
    ```


    :param str slug: The unique URL slug for this organization.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryOrganization:getSentryOrganization', __args__, opts=opts, typ=GetSentryOrganizationResult)
    return __ret__.apply(lambda __response__: GetSentryOrganizationResult(
        id=pulumi.get(__response__, 'id'),
        internal_id=pulumi.get(__response__, 'internal_id'),
        name=pulumi.get(__response__, 'name'),
        slug=pulumi.get(__response__, 'slug')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryOrganizationMemberArgs', 'SentryOrganizationMember']

@pulumi.input_type
class SentryOrganizationMemberArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 organization: pulumi.Input[str],
                 role: pulumi.Input[str],
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SentryOrganizationMember resource.
        :param pulumi.Input[str] email: The email of the organization member.
        :param pulumi.Input[str] organization: The slug of the organization the user should be invited to.
        :param pulumi.Input[str] role: This is the role of the organization member.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The teams the organization member should be added to.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "role", role)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The email of the organization member.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the user should be invited to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        """
        This is the role of the organization member.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The teams the organization member should be added to.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "teams", value)


@pulumi.input_type
class _SentryOrganizationMemberState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[str]] = None,
                 expired: Optional[pulumi.Input[bool]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 pending: Optional[pulumi.Input[bool]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SentryOrganizationMember resources.
        :param pulumi.Input[str] email: The email of the organization member.
        :param pulumi.Input[bool] expired: The invite has expired.
        :param pulumi.Input[str] internal_id: The internal ID for this organization membership.
        :param pulumi.Input[str] organization: The slug of the organization the user should be invited to.
        :param pulumi.Input[bool] pending: The invite is pending.
        :param pulumi.Input[str] role: This is the role of the organization member.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The teams the organization member should be added to.
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if expired is not None:
            pulumi.set(__self__, "expired", expired)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if pending is not None:
            pulumi.set(__self__, "pending", pending)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        The email of the organization member.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def expired(self) -> Optional[pulumi.Input[bool]]:
        """
        The invite has expired.
        """
        return pulumi.get(self, "expired")

    @expired.setter
    def expired(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expired", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this organization membership.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the user should be invited to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def pending(self) -> Optional[pulumi.Input[bool]]:
        """
        The invite is pending.
        """
        return pulumi.get(self, "pending")

    @pending.setter
    def pending(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "pending", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        This is the role of the organization member.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The teams the organization member should be added to.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "teams", value)


class SentryOrganizationMember(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create an organization member
        john_doe = sentry.SentryOrganizationMember("john_doe",
            organization="my-organization",
            email="test@example.com",
            role="member",
            teams=["my-team"])
        ```

        ## Import

        import using the organization, membership id from the URL:

        https://sentry.io/settings/[org-slug]/members/[member-id]/

        ```sh
        $ pulumi import sentry:index/sentryOrganizationMember:SentryOrganizationMember john_doe org-slug/member-id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The email of the organization member.
        :param pulumi.Input[str] organization: The slug of the organization the user should be invited to.
        :param pulumi.Input[str] role: This is the role of the organization member.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The teams the organization member should be added to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryOrganizationMemberArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create an organization member
        john_doe = sentry.SentryOrganizationMember("john_doe",
            organization="my-organization",
            email="test@example.com",
            role="member",
            teams=["my-team"])
        ```

        ## Import

        import using the organization, membership id from the URL:

        https://sentry.io/settings/[org-slug]/members/[member-id]/

        ```sh
        $ pulumi import sentry:index/sentryOrganizationMember:SentryOrganizationMember john_doe org-slug/member-id
        ```

        :param str resource_name: The name of the resource.
        :param SentryOrganizationMemberArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryOrganizationMemberArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryOrganizationMemberArgs.__new__(SentryOrganizationMemberArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            __props__.__dict__["teams"] = teams
            __props__.__dict__["expired"] = None
            __props__.__dict__["internal_id"] = None
            __props__.__dict__["pending"] = None
        super(SentryOrganizationMember, __self__).__init__(
            'sentry:index/sentryOrganizationMember:SentryOrganizationMember',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[str]] = None,
            expired: Optional[pulumi.Input[bool]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            pending: Optional[pulumi.Input[bool]] = None,
            role: Optional[pulumi.Input[str]] = None,
            teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SentryOrganizationMember':
        """
        Get an existing SentryOrganizationMember resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The email of the organization member.
        :param pulumi.Input[bool] expired: The invite has expired.
        :param pulumi.Input[str] internal_id: The internal ID for this organization membership.
        :param pulumi.Input[str] organization: The slug of the organization the user should be invited to.
        :param pulumi.Input[bool] pending: The invite is pending.
        :param pulumi.Input[str] role: This is the role of the organization member.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The teams the organization member should be added to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryOrganizationMemberState.__new__(_SentryOrganizationMemberState)

        __props__.__dict__["email"] = email
        __props__.__dict__["expired"] = expired
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["organization"] = organization
        __props__.__dict__["pending"] = pending
        __props__.__dict__["role"] = role
        __props__.__dict__["teams"] = teams
        return SentryOrganizationMember(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The email of the organization member.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def expired(self) -> pulumi.Output[bool]:
        """
        The invite has expired.
        """
        return pulumi.get(self, "expired")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this organization membership.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the user should be invited to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def pending(self) -> pulumi.Output[bool]:
        """
        The invite is pending.
        """
        return pulumi.get(self, "pending")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        This is the role of the organization member.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def teams(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The teams the organization member should be added to.
        """
        return pulumi.get(self, "teams")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .get_sentry_dashboard import *
from .get_sentry_issue_alert import *
from .get_sentry_key import *
from .get_sentry_metric_alert import *
from .get_sentry_organization import *
from .get_sentry_organization_integration import *
from .get_sentry_team import *
from .provider import *
from .sentry_dashboard import *
from .sentry_issue_alert import *
from .sentry_key import *
from .sentry_metric_alert import *
from .sentry_organization import *
from .sentry_organization_code_mapping import *
from .sentry_organization_member import *
from .sentry_organization_repository_github import *
from .sentry_plugin import *
from .sentry_project import *
from .sentry_rule import *
from .sentry_team import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_sentry.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_sentry.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "sentry",
  "mod": "index/sentryDashboard",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryDashboard:SentryDashboard": "SentryDashboard"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryIssueAlert",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryIssueAlert:SentryIssueAlert": "SentryIssueAlert"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryKey",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryKey:SentryKey": "SentryKey"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryMetricAlert",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryMetricAlert:SentryMetricAlert": "SentryMetricAlert"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganization",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganization:SentryOrganization": "SentryOrganization"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganizationCodeMapping",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganizationCodeMapping:SentryOrganizationCodeMapping": "SentryOrganizationCodeMapping"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganizationMember",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganizationMember:SentryOrganizationMember": "SentryOrganizationMember"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganizationRepositoryGithub",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganizationRepositoryGithub:SentryOrganizationRepositoryGithub": "SentryOrganizationRepositoryGithub"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryPlugin",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryPlugin:SentryPlugin": "SentryPlugin"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryProject",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryProject:SentryProject": "SentryProject"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryRule",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryRule:SentryRule": "SentryRule"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryTeam",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryTeam:SentryTeam": "SentryTeam"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "sentry",
  "token": "pulumi:providers:sentry",
  "fqn": "pulumiverse_sentry",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'SentryDashboardWidget',
    'SentryDashboardWidgetLayout',
    'SentryDashboardWidgetQuery',
    'SentryMetricAlertTrigger',
    'SentryMetricAlertTriggerAction',
    'GetSentryDashboardWidgetResult',
    'GetSentryDashboardWidgetLayoutResult',
    'GetSentryDashboardWidgetQueryResult',
    'GetSentryMetricAlertTriggerResult',
    'GetSentryMetricAlertTriggerActionResult',
]

@pulumi.output_type
class SentryDashboardWidget(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "displayType":
            suggest = "display_type"
        elif key == "widgetType":
            suggest = "widget_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SentryDashboardWidget. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SentryDashboardWidget.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SentryDashboardWidget.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 display_type: str,
                 layout: 'outputs.SentryDashboardWidgetLayout',
                 queries: Sequence['outputs.SentryDashboardWidgetQuery'],
                 title: str,
                 id: Optional[str] = None,
                 interval: Optional[str] = None,
                 limit: Optional[int] = None,
                 widget_type: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        pulumi.set(__self__, "display_type", display_type)
        pulumi.set(__self__, "layout", layout)
        pulumi.set(__self__, "queries", queries)
        pulumi.set(__self__, "title", title)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if limit is not None:
            pulumi.set(__self__, "limit", limit)
        if widget_type is not None:
            pulumi.set(__self__, "widget_type", widget_type)

    @property
    @pulumi.getter(name="displayType")
    def display_type(self) -> str:
        return pulumi.get(self, "display_type")

    @property
    @pulumi.getter
    def layout(self) -> 'outputs.SentryDashboardWidgetLayout':
        return pulumi.get(self, "layout")

    @property
    @pulumi.getter
    def queries(self) -> Sequence['outputs.SentryDashboardWidgetQuery']:
        return pulumi.get(self, "queries")

    @property
    @pulumi.getter
    def title(self) -> str:
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def interval(self) -> Optional[str]:
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter
    def limit(self) -> Optional[int]:
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter(name="widgetType")
    def widget_type(self) -> Optional[str]:
        return pulumi.get(self, "widget_type")


@pulumi.output_type
class SentryDashboardWidgetLayout(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "minH":
            suggest = "min_h"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SentryDashboardWidgetLayout. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SentryDashboardWidgetLayout.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SentryDashboardWidgetLayout.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 h: int,
                 min_h: int,
                 w: int,
                 x: int,
                 y: int):
        pulumi.set(__self__, "h", h)
        pulumi.set(__self__, "min_h", min_h)
        pulumi.set(__self__, "w", w)
        pulumi.set(__self__, "x", x)
        pulumi.set(__self__, "y", y)

    @property
    @pulumi.getter
    def h(self) -> int:
        return pulumi.get(self, "h")

    @property
    @pulumi.getter(name="minH")
    def min_h(self) -> int:
        return pulumi.get(self, "min_h")

    @property
    @pulumi.getter
    def w(self) -> int:
        return pulumi.get(self, "w")

    @property
    @pulumi.getter
    def x(self) -> int:
        return pulumi.get(self, "x")

    @property
    @pulumi.getter
    def y(self) -> int:
        return pulumi.get(self, "y")


@pulumi.output_type
class SentryDashboardWidgetQuery(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldAliases":
            suggest = "field_aliases"
        elif key == "orderBy":
            suggest = "order_by"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SentryDashboardWidgetQuery. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SentryDashboardWidgetQuery.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SentryDashboardWidgetQuery.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 aggregates: Optional[Sequence[str]] = None,
                 columns: Optional[Sequence[str]] = None,
                 conditions: Optional[str] = None,
                 field_aliases: Optional[Sequence[str]] = None,
                 fields: Optional[Sequence[str]] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 order_by: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        if aggregates is not None:
            pulumi.set(__self__, "aggregates", aggregates)
        if columns is not None:
            pulumi.set(__self__, "columns", columns)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if field_aliases is not None:
            pulumi.set(__self__, "field_aliases", field_aliases)
        if fields is not None:
            pulumi.set(__self__, "fields", fields)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if order_by is not None:
            pulumi.set(__self__, "order_by", order_by)

    @property
    @pulumi.getter
    def aggregates(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "aggregates")

    @property
    @pulumi.getter
    def columns(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "columns")

    @property
    @pulumi.getter
    def conditions(self) -> Optional[str]:
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="fieldAliases")
    def field_aliases(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "field_aliases")

    @property
    @pulumi.getter
    def fields(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "fields")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[str]:
        return pulumi.get(self, "order_by")


@pulumi.output_type
class SentryMetricAlertTrigger(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "alertThreshold":
            suggest = "alert_threshold"
        elif key == "thresholdType":
            suggest = "threshold_type"
        elif key == "resolveThreshold":
            suggest = "resolve_threshold"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SentryMetricAlertTrigger. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SentryMetricAlertTrigger.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SentryMetricAlertTrigger.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 alert_threshold: float,
                 label: str,
                 threshold_type: int,
                 actions: Optional[Sequence['outputs.SentryMetricAlertTriggerAction']] = None,
                 id: Optional[str] = None,
                 resolve_threshold: Optional[float] = None):
        """
        :param str id: The ID of this resource.
        """
        pulumi.set(__self__, "alert_threshold", alert_threshold)
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "threshold_type", threshold_type)
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if resolve_threshold is not None:
            pulumi.set(__self__, "resolve_threshold", resolve_threshold)

    @property
    @pulumi.getter(name="alertThreshold")
    def alert_threshold(self) -> float:
        return pulumi.get(self, "alert_threshold")

    @property
    @pulumi.getter
    def label(self) -> str:
        return pulumi.get(self, "label")

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> int:
        return pulumi.get(self, "threshold_type")

    @property
    @pulumi.getter
    def actions(self) -> Optional[Sequence['outputs.SentryMetricAlertTriggerAction']]:
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> Optional[float]:
        return pulumi.get(self, "resolve_threshold")


@pulumi.output_type
class SentryMetricAlertTriggerAction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "targetType":
            suggest = "target_type"
        elif key == "integrationId":
            suggest = "integration_id"
        elif key == "targetIdentifier":
            suggest = "target_identifier"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SentryMetricAlertTriggerAction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SentryMetricAlertTriggerAction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SentryMetricAlertTriggerAction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 target_type: str,
                 type: str,
                 id: Optional[str] = None,
                 integration_id: Optional[int] = None,
                 target_identifier: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        pulumi.set(__self__, "target_type", target_type)
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if integration_id is not None:
            pulumi.set(__self__, "integration_id", integration_id)
        if target_identifier is not None:
            pulumi.set(__self__, "target_identifier", target_identifier)

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> str:
        return pulumi.get(self, "target_type")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> Optional[int]:
        return pulumi.get(self, "integration_id")

    @property
    @pulumi.getter(name="targetIdentifier")
    def target_identifier(self) -> Optional[str]:
        return pulumi.get(self, "target_identifier")


@pulumi.output_type
class GetSentryDashboardWidgetResult(dict):
    def __init__(__self__, *,
                 display_type: str,
                 id: str,
                 interval: str,
                 layouts: Sequence['outputs.GetSentryDashboardWidgetLayoutResult'],
                 limit: int,
                 queries: Sequence['outputs.GetSentryDashboardWidgetQueryResult'],
                 title: str,
                 widget_type: str):
        pulumi.set(__self__, "display_type", display_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "layouts", layouts)
        pulumi.set(__self__, "limit", limit)
        pulumi.set(__self__, "queries", queries)
        pulumi.set(__self__, "title", title)
        pulumi.set(__self__, "widget_type", widget_type)

    @property
    @pulumi.getter(name="displayType")
    def display_type(self) -> str:
        return pulumi.get(self, "display_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def interval(self) -> str:
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter
    def layouts(self) -> Sequence['outputs.GetSentryDashboardWidgetLayoutResult']:
        return pulumi.get(self, "layouts")

    @property
    @pulumi.getter
    def limit(self) -> int:
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter
    def queries(self) -> Sequence['outputs.GetSentryDashboardWidgetQueryResult']:
        return pulumi.get(self, "queries")

    @property
    @pulumi.getter
    def title(self) -> str:
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="widgetType")
    def widget_type(self) -> str:
        return pulumi.get(self, "widget_type")


@pulumi.output_type
class GetSentryDashboardWidgetLayoutResult(dict):
    def __init__(__self__, *,
                 h: int,
                 min_h: int,
                 w: int,
                 x: int,
                 y: int):
        pulumi.set(__self__, "h", h)
        pulumi.set(__self__, "min_h", min_h)
        pulumi.set(__self__, "w", w)
        pulumi.set(__self__, "x", x)
        pulumi.set(__self__, "y", y)

    @property
    @pulumi.getter
    def h(self) -> int:
        return pulumi.get(self, "h")

    @property
    @pulumi.getter(name="minH")
    def min_h(self) -> int:
        return pulumi.get(self, "min_h")

    @property
    @pulumi.getter
    def w(self) -> int:
        return pulumi.get(self, "w")

    @property
    @pulumi.getter
    def x(self) -> int:
        return pulumi.get(self, "x")

    @property
    @pulumi.getter
    def y(self) -> int:
        return pulumi.get(self, "y")


@pulumi.output_type
class GetSentryDashboardWidgetQueryResult(dict):
    def __init__(__self__, *,
                 aggregates: Sequence[str],
                 columns: Sequence[str],
                 conditions: str,
                 field_aliases: Sequence[str],
                 fields: Sequence[str],
                 id: str,
                 name: str,
                 order_by: str):
        pulumi.set(__self__, "aggregates", aggregates)
        pulumi.set(__self__, "columns", columns)
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "field_aliases", field_aliases)
        pulumi.set(__self__, "fields", fields)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "order_by", order_by)

    @property
    @pulumi.getter
    def aggregates(self) -> Sequence[str]:
        return pulumi.get(self, "aggregates")

    @property
    @pulumi.getter
    def columns(self) -> Sequence[str]:
        return pulumi.get(self, "columns")

    @property
    @pulumi.getter
    def conditions(self) -> str:
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="fieldAliases")
    def field_aliases(self) -> Sequence[str]:
        return pulumi.get(self, "field_aliases")

    @property
    @pulumi.getter
    def fields(self) -> Sequence[str]:
        return pulumi.get(self, "fields")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> str:
        return pulumi.get(self, "order_by")


@pulumi.output_type
class GetSentryMetricAlertTriggerResult(dict):
    def __init__(__self__, *,
                 actions: Sequence['outputs.GetSentryMetricAlertTriggerActionResult'],
                 alert_threshold: float,
                 id: str,
                 label: str,
                 resolve_threshold: float,
                 threshold_type: int):
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "alert_threshold", alert_threshold)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "resolve_threshold", resolve_threshold)
        pulumi.set(__self__, "threshold_type", threshold_type)

    @property
    @pulumi.getter
    def actions(self) -> Sequence['outputs.GetSentryMetricAlertTriggerActionResult']:
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter(name="alertThreshold")
    def alert_threshold(self) -> float:
        return pulumi.get(self, "alert_threshold")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def label(self) -> str:
        return pulumi.get(self, "label")

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> float:
        return pulumi.get(self, "resolve_threshold")

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> int:
        return pulumi.get(self, "threshold_type")


@pulumi.output_type
class GetSentryMetricAlertTriggerActionResult(dict):
    def __init__(__self__, *,
                 id: str,
                 integration_id: int,
                 target_identifier: str,
                 target_type: str,
                 type: str):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "integration_id", integration_id)
        pulumi.set(__self__, "target_identifier", target_identifier)
        pulumi.set(__self__, "target_type", target_type)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> int:
        return pulumi.get(self, "integration_id")

    @property
    @pulumi.getter(name="targetIdentifier")
    def target_identifier(self) -> str:
        return pulumi.get(self, "target_identifier")

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> str:
        return pulumi.get(self, "target_type")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSentryKeyResult',
    'AwaitableGetSentryKeyResult',
    'get_sentry_key',
    'get_sentry_key_output',
]

@pulumi.output_type
class GetSentryKeyResult:
    """
    A collection of values returned by getSentryKey.
    """
    def __init__(__self__, dsn_csp=None, dsn_public=None, dsn_secret=None, first=None, id=None, is_active=None, name=None, organization=None, project=None, project_id=None, public=None, rate_limit_count=None, rate_limit_window=None, secret=None):
        if dsn_csp and not isinstance(dsn_csp, str):
            raise TypeError("Expected argument 'dsn_csp' to be a str")
        pulumi.set(__self__, "dsn_csp", dsn_csp)
        if dsn_public and not isinstance(dsn_public, str):
            raise TypeError("Expected argument 'dsn_public' to be a str")
        pulumi.set(__self__, "dsn_public", dsn_public)
        if dsn_secret and not isinstance(dsn_secret, str):
            raise TypeError("Expected argument 'dsn_secret' to be a str")
        pulumi.set(__self__, "dsn_secret", dsn_secret)
        if first and not isinstance(first, bool):
            raise TypeError("Expected argument 'first' to be a bool")
        pulumi.set(__self__, "first", first)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_active and not isinstance(is_active, bool):
            raise TypeError("Expected argument 'is_active' to be a bool")
        pulumi.set(__self__, "is_active", is_active)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if project_id and not isinstance(project_id, int):
            raise TypeError("Expected argument 'project_id' to be a int")
        pulumi.set(__self__, "project_id", project_id)
        if public and not isinstance(public, str):
            raise TypeError("Expected argument 'public' to be a str")
        pulumi.set(__self__, "public", public)
        if rate_limit_count and not isinstance(rate_limit_count, int):
            raise TypeError("Expected argument 'rate_limit_count' to be a int")
        pulumi.set(__self__, "rate_limit_count", rate_limit_count)
        if rate_limit_window and not isinstance(rate_limit_window, int):
            raise TypeError("Expected argument 'rate_limit_window' to be a int")
        pulumi.set(__self__, "rate_limit_window", rate_limit_window)
        if secret and not isinstance(secret, str):
            raise TypeError("Expected argument 'secret' to be a str")
        pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="dsnCsp")
    def dsn_csp(self) -> str:
        """
        DSN for the Content Security Policy (CSP) for the key.
        """
        return pulumi.get(self, "dsn_csp")

    @property
    @pulumi.getter(name="dsnPublic")
    def dsn_public(self) -> str:
        """
        DSN for the key.
        """
        return pulumi.get(self, "dsn_public")

    @property
    @pulumi.getter(name="dsnSecret")
    @_utilities.deprecated("""DSN (Deprecated) for the key.""")
    def dsn_secret(self) -> str:
        return pulumi.get(self, "dsn_secret")

    @property
    @pulumi.getter
    def first(self) -> Optional[bool]:
        """
        Boolean flag indicating that we want the first key of the returned keys.
        """
        return pulumi.get(self, "first")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isActive")
    def is_active(self) -> bool:
        """
        Flag indicating the key is active.
        """
        return pulumi.get(self, "is_active")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the key to retrieve.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The slug of the organization the key should be created for.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The slug of the project the key should be created for.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> int:
        """
        The ID of the project that the key belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def public(self) -> str:
        """
        Public key portion of the client key.
        """
        return pulumi.get(self, "public")

    @property
    @pulumi.getter(name="rateLimitCount")
    def rate_limit_count(self) -> int:
        """
        Number of events that can be reported within the rate limit window.
        """
        return pulumi.get(self, "rate_limit_count")

    @property
    @pulumi.getter(name="rateLimitWindow")
    def rate_limit_window(self) -> int:
        """
        Length of time that will be considered when checking the rate limit.
        """
        return pulumi.get(self, "rate_limit_window")

    @property
    @pulumi.getter
    def secret(self) -> str:
        """
        Secret key portion of the client key.
        """
        return pulumi.get(self, "secret")


class AwaitableGetSentryKeyResult(GetSentryKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryKeyResult(
            dsn_csp=self.dsn_csp,
            dsn_public=self.dsn_public,
            dsn_secret=self.dsn_secret,
            first=self.first,
            id=self.id,
            is_active=self.is_active,
            name=self.name,
            organization=self.organization,
            project=self.project,
            project_id=self.project_id,
            public=self.public,
            rate_limit_count=self.rate_limit_count,
            rate_limit_window=self.rate_limit_window,
            secret=self.secret)


def get_sentry_key(first: Optional[bool] = None,
                   name: Optional[str] = None,
                   organization: Optional[str] = None,
                   project: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryKeyResult:
    """
    Sentry Key data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve a project key by name
    default = sentry.get_sentry_key(organization="my-organization",
        project="web-app",
        name="Default")
    # Retrieve the first key of a project
    first = sentry.get_sentry_key(organization="my-organization",
        project="web-app",
        first=True)
    ```


    :param bool first: Boolean flag indicating that we want the first key of the returned keys.
    :param str name: The name of the key to retrieve.
    :param str organization: The slug of the organization the key should be created for.
    :param str project: The slug of the project the key should be created for.
    """
    __args__ = dict()
    __args__['first'] = first
    __args__['name'] = name
    __args__['organization'] = organization
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryKey:getSentryKey', __args__, opts=opts, typ=GetSentryKeyResult).value

    return AwaitableGetSentryKeyResult(
        dsn_csp=pulumi.get(__ret__, 'dsn_csp'),
        dsn_public=pulumi.get(__ret__, 'dsn_public'),
        dsn_secret=pulumi.get(__ret__, 'dsn_secret'),
        first=pulumi.get(__ret__, 'first'),
        id=pulumi.get(__ret__, 'id'),
        is_active=pulumi.get(__ret__, 'is_active'),
        name=pulumi.get(__ret__, 'name'),
        organization=pulumi.get(__ret__, 'organization'),
        project=pulumi.get(__ret__, 'project'),
        project_id=pulumi.get(__ret__, 'project_id'),
        public=pulumi.get(__ret__, 'public'),
        rate_limit_count=pulumi.get(__ret__, 'rate_limit_count'),
        rate_limit_window=pulumi.get(__ret__, 'rate_limit_window'),
        secret=pulumi.get(__ret__, 'secret'))
def get_sentry_key_output(first: Optional[pulumi.Input[Optional[bool]]] = None,
                          name: Optional[pulumi.Input[Optional[str]]] = None,
                          organization: Optional[pulumi.Input[str]] = None,
                          project: Optional[pulumi.Input[str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryKeyResult]:
    """
    Sentry Key data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve a project key by name
    default = sentry.get_sentry_key(organization="my-organization",
        project="web-app",
        name="Default")
    # Retrieve the first key of a project
    first = sentry.get_sentry_key(organization="my-organization",
        project="web-app",
        first=True)
    ```


    :param bool first: Boolean flag indicating that we want the first key of the returned keys.
    :param str name: The name of the key to retrieve.
    :param str organization: The slug of the organization the key should be created for.
    :param str project: The slug of the project the key should be created for.
    """
    __args__ = dict()
    __args__['first'] = first
    __args__['name'] = name
    __args__['organization'] = organization
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryKey:getSentryKey', __args__, opts=opts, typ=GetSentryKeyResult)
    return __ret__.apply(lambda __response__: GetSentryKeyResult(
        dsn_csp=pulumi.get(__response__, 'dsn_csp'),
        dsn_public=pulumi.get(__response__, 'dsn_public'),
        dsn_secret=pulumi.get(__response__, 'dsn_secret'),
        first=pulumi.get(__response__, 'first'),
        id=pulumi.get(__response__, 'id'),
        is_active=pulumi.get(__response__, 'is_active'),
        name=pulumi.get(__response__, 'name'),
        organization=pulumi.get(__response__, 'organization'),
        project=pulumi.get(__response__, 'project'),
        project_id=pulumi.get(__response__, 'project_id'),
        public=pulumi.get(__response__, 'public'),
        rate_limit_count=pulumi.get(__response__, 'rate_limit_count'),
        rate_limit_window=pulumi.get(__response__, 'rate_limit_window'),
        secret=pulumi.get(__response__, 'secret')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSentryOrganizationIntegrationResult',
    'AwaitableGetSentryOrganizationIntegrationResult',
    'get_sentry_organization_integration',
    'get_sentry_organization_integration_output',
]

@pulumi.output_type
class GetSentryOrganizationIntegrationResult:
    """
    A collection of values returned by getSentryOrganizationIntegration.
    """
    def __init__(__self__, id=None, internal_id=None, name=None, organization=None, provider_key=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_id and not isinstance(internal_id, str):
            raise TypeError("Expected argument 'internal_id' to be a str")
        pulumi.set(__self__, "internal_id", internal_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if provider_key and not isinstance(provider_key, str):
            raise TypeError("Expected argument 'provider_key' to be a str")
        pulumi.set(__self__, "provider_key", provider_key)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> str:
        """
        The internal ID for this organization integration.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the organization integration.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The slug of the organization the integration belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="providerKey")
    def provider_key(self) -> str:
        """
        The key of the organization integration provider.
        """
        return pulumi.get(self, "provider_key")


class AwaitableGetSentryOrganizationIntegrationResult(GetSentryOrganizationIntegrationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryOrganizationIntegrationResult(
            id=self.id,
            internal_id=self.internal_id,
            name=self.name,
            organization=self.organization,
            provider_key=self.provider_key)


def get_sentry_organization_integration(name: Optional[str] = None,
                                        organization: Optional[str] = None,
                                        provider_key: Optional[str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryOrganizationIntegrationResult:
    """
    Sentry Organization Integration data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve a Github organization integration
    github = sentry.get_sentry_organization_integration(organization="my-organization",
        provider_key="github",
        name="my-github-organization")
    # Retrieve a Slack integration
    slack = sentry.get_sentry_organization_integration(organization="my-organization",
        provider_key="slack",
        name="Slack Workspace")
    ```


    :param str name: The name of the organization integration.
    :param str organization: The slug of the organization the integration belongs to.
    :param str provider_key: The key of the organization integration provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['organization'] = organization
    __args__['providerKey'] = provider_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryOrganizationIntegration:getSentryOrganizationIntegration', __args__, opts=opts, typ=GetSentryOrganizationIntegrationResult).value

    return AwaitableGetSentryOrganizationIntegrationResult(
        id=pulumi.get(__ret__, 'id'),
        internal_id=pulumi.get(__ret__, 'internal_id'),
        name=pulumi.get(__ret__, 'name'),
        organization=pulumi.get(__ret__, 'organization'),
        provider_key=pulumi.get(__ret__, 'provider_key'))
def get_sentry_organization_integration_output(name: Optional[pulumi.Input[str]] = None,
                                               organization: Optional[pulumi.Input[str]] = None,
                                               provider_key: Optional[pulumi.Input[str]] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryOrganizationIntegrationResult]:
    """
    Sentry Organization Integration data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry

    # Retrieve a Github organization integration
    github = sentry.get_sentry_organization_integration(organization="my-organization",
        provider_key="github",
        name="my-github-organization")
    # Retrieve a Slack integration
    slack = sentry.get_sentry_organization_integration(organization="my-organization",
        provider_key="slack",
        name="Slack Workspace")
    ```


    :param str name: The name of the organization integration.
    :param str organization: The slug of the organization the integration belongs to.
    :param str provider_key: The key of the organization integration provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['organization'] = organization
    __args__['providerKey'] = provider_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryOrganizationIntegration:getSentryOrganizationIntegration', __args__, opts=opts, typ=GetSentryOrganizationIntegrationResult)
    return __ret__.apply(lambda __response__: GetSentryOrganizationIntegrationResult(
        id=pulumi.get(__response__, 'id'),
        internal_id=pulumi.get(__response__, 'internal_id'),
        name=pulumi.get(__response__, 'name'),
        organization=pulumi.get(__response__, 'organization'),
        provider_key=pulumi.get(__response__, 'provider_key')))
